autowisp.processor module — AutoWISP documentation

# autowisp.processor module

## Class Inheritance Diagram

Define base class for all pipeline processing steps enforcing conventions.

class autowisp.processor.Processor(**configuration)

  Bases: `object`

  Providing and enforcing uniform interface for config, recovery, and logging.

  __call__(**configuration)

    Add/overwrite any configuration parameters at time of processing.

  __init__(**configuration)

    Prepare to process with the given configuration.

  default_configuration = {}